@@ -190,6 +190,9 @@ g_content_type_get_icon (const char *type)
      <type>: <value>
      REG_EXPAND_SZ: %SystemRoot%\System32\Wscript.exe,3
      REG_SZ: shimgvw.dll,3
+
+     gtkfilesystemwin32.c in gtk-2-12 is probably a good place to look
+     for inspiration.
   */
   return NULL;
 }
@@ -203,6 +206,18 @@ g_content_type_can_be_executable (const char *type)
       strcmp (type, ".com") == 0 ||
       strcmp (type, ".bat") == 0)
     return TRUE;
+
+  /* TODO: Also look at PATHEXT, which lists the extensions for
+   * "scripts" in addition to those for true binary executables.
+   *
+   * (PATHEXT=.COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH for me
+   * right now, for instance). And in a sense, all associated file
+   * types are "executable" on Windows... You can just type foo.jpg as
+   * a command name in cmd.exe, and it will run the application
+   * associated with .jpg. Hard to say what this API actually means
+   * with "executable".
+   */
+
   return FALSE;
 }
 
@@ -221,6 +236,20 @@ looks_like_text (const guchar *data,
   return TRUE;
 }
 
+char *
+g_content_type_from_mime_type (const char *mime_type)
+{
+  char *key, *content_type;
+
+  g_return_val_if_fail (mime_type != NULL, NULL);
+
+  key = g_strconcat ("MIME\\DataBase\\Content Type\\", mime_type, NULL);
+  content_type = get_registry_classes_key (key, L"Extension");
+  g_free (key);
+
+  return content_type;
+}
+
 char *
 g_content_type_guess (const char   *filename,
 		      const guchar *data,
@@ -644,38 +673,51 @@ g_content_type_get_mime_type (const char *type)
 GIcon *
 g_content_type_get_icon (const char *type)
 {
-  char *mimetype_icon, *generic_mimetype_icon, *p;
-  char *icon_names[3];
-  GThemedIcon *themed_icon;
+  char *mimetype_icon, *generic_mimetype_icon, *q;
+  char *xdg_mimetype_icon, *legacy_mimetype_icon;
+  char *icon_names[4];
+  int n = 0;
+  const char *p;
+  GIcon *themed_icon;
   
   g_return_val_if_fail (type != NULL, NULL);
   
+  G_LOCK (gio_xdgmime);
+  xdg_mimetype_icon = g_strdup (xdg_mime_get_icon (type));
+  G_UNLOCK (gio_xdgmime);
+
   mimetype_icon = g_strdup (type);
   
-  while ((p = strchr (mimetype_icon, '/')) != NULL)
-    *p = '-';
+  while ((q = strchr (mimetype_icon, '/')) != NULL)
+    *q = '-';
   
   p = strchr (type, '/');
   if (p == NULL)
     p = type + strlen (type);
+
+  /* Not all icons have migrated to the new icon theme spec, look for old names too */
+  legacy_mimetype_icon = g_strconcat ("gnome-mime-", mimetype_icon, NULL);
   
   generic_mimetype_icon = g_malloc (p - type + strlen ("-x-generic") + 1);
   memcpy (generic_mimetype_icon, type, p - type);
   memcpy (generic_mimetype_icon + (p - type), "-x-generic", strlen ("-x-generic"));
   generic_mimetype_icon[(p - type) + strlen ("-x-generic")] = 0;
   
-  icon_names[0] = mimetype_icon;
-  /* Not all icons have migrated to the new icon theme spec, look for old names too */
-  icon_names[1] = g_strconcat ("gnome-mime-", mimetype_icon, NULL);
-  icon_names[2] = generic_mimetype_icon;
+  if (xdg_mimetype_icon)
+    icon_names[n++] = xdg_mimetype_icon;
+
+  icon_names[n++] = mimetype_icon;
+  icon_names[n++] = legacy_mimetype_icon;
+  icon_names[n++] = generic_mimetype_icon;
   
-  themed_icon = g_themed_icon_new_from_names (icon_names, 3);
+  themed_icon = g_themed_icon_new_from_names (icon_names, n);
   
+  g_free (xdg_mimetype_icon);
   g_free (mimetype_icon);
-  g_free (icon_names[1]);
+  g_free (legacy_mimetype_icon);
   g_free (generic_mimetype_icon);
   
-  return G_ICON (themed_icon);
+  return themed_icon;
 }
 
 /**
@@ -717,6 +759,25 @@ looks_like_text (const guchar *data, gsize data_size)
   return TRUE;
 }
 
+/**
+ * g_content_type_from_mime_type:
+ * @mime_type: a mime type string.
+ *
+ * Tries to find a content type based on the mime type name.
+ *
+ * Returns: Newly allocated string with content type or NULL when does not know.
+ *
+ * Since: 2.18
+ **/
+char *
+g_content_type_from_mime_type (const char *mime_type)
+{
+  g_return_val_if_fail (mime_type != NULL, NULL);
+
+  /* mime type and content type are same on unixes */
+  return g_strdup (mime_type);
+}
+
 /**
  * g_content_type_guess:
  * @filename: a string.
@@ -811,7 +872,7 @@ g_content_type_guess (const char   *filename,
       
       if (mimetype == NULL)
 	{
-	  /* Conflicts, and sniffed type was no help or not there. guess on the first one */
+	  /* Conflicts, and sniffed type was no help or not there. Guess on the first one */
 	  mimetype = g_strdup (name_mimetypes[0]);
 	  if (result_uncertain)
 	    *result_uncertain = TRUE;
