@@ -75,7 +75,7 @@ typedef enum  {
  * Flags used when mounting a mount.
  */
 typedef enum  {
-  G_MOUNT_MOUNT_NONE = 0,
+  G_MOUNT_MOUNT_NONE = 0
 } GMountMountFlags;
 
 
@@ -187,7 +187,7 @@ typedef gboolean (* GFileReadMoreCallback) (const char *file_contents,
  * @get_uri: Gets a URI for the path within a #GFile.
  * @get_parse_name: Gets the parsed name for the #GFile.
  * @get_parent: Gets the parent directory for the #GFile.
- * @contains_file: Checks whether a #GFile contains a specified file.
+ * @prefix_matches: Checks whether a #GFile contains a specified file.
  * @get_relative_path: Gets the path for a #GFile relative to a given path.
  * @resolve_relative_path: Resolves a relative path for a #GFile to an absolute path.
  * @get_child_for_display_name: Gets the child #GFile for a given display name.
@@ -198,8 +198,8 @@ typedef gboolean (* GFileReadMoreCallback) (const char *file_contents,
  * @query_info_async: Asynchronously gets the #GFileInfo for a #GFile.
  * @query_info_finish: Finishes an asynchronous query info operation.
  * @query_filesystem_info: Gets a #GFileInfo for the file system #GFile is on.
- * @_query_filesystem_info_async: Asynchronously gets a #GFileInfo for the file system #GFile is on.
- * @_query_filesystem_info_finish: Finishes asynchronously getting the file system info.
+ * @query_filesystem_info_async: Asynchronously gets a #GFileInfo for the file system #GFile is on.
+ * @query_filesystem_info_finish: Finishes asynchronously getting the file system info.
  * @find_enclosing_mount: Gets a #GMount for the #GFile.
  * @find_enclosing_mount_async: Asynchronously gets the #GMount for a #GFile.
  * @find_enclosing_mount_finish: Finishes asynchronously getting the volume.
@@ -278,8 +278,8 @@ struct _GFileIface
   char *              (*get_uri)                    (GFile         *file);
   char *              (*get_parse_name)             (GFile         *file);
   GFile *             (*get_parent)                 (GFile         *file);
-  gboolean            (*contains_file)              (GFile         *parent,
-						     GFile         *descendant);
+  gboolean            (*prefix_matches)             (GFile         *prefix,
+						     GFile         *file);
   char *              (*get_relative_path)          (GFile         *parent,
 						     GFile         *descendant);
   GFile *             (*resolve_relative_path)      (GFile        *file,
@@ -324,8 +324,15 @@ struct _GFileIface
 					     const char           *attributes,
 					     GCancellable         *cancellable,
 					     GError              **error);
-  void                (*_query_filesystem_info_async) (void);
-  void                (*_query_filesystem_info_finish) (void);
+  void                (*query_filesystem_info_async) (GFile                *file,
+                                                      const char           *attributes,
+                                                      int                   io_priority,
+                                                      GCancellable         *cancellable,
+                                                      GAsyncReadyCallback   callback,
+                                                      gpointer              user_data);
+  GFileInfo *         (*query_filesystem_info_finish) (GFile                *file,
+                                                       GAsyncResult         *res,
+                                                       GError              **error);
   
   GMount *            (*find_enclosing_mount)(GFile              *file,
 					       GCancellable       *cancellable,
@@ -573,8 +580,8 @@ GFile *                 g_file_get_child                  (GFile
 GFile *                 g_file_get_child_for_display_name (GFile                      *file,
 							   const char                 *display_name,
 							   GError                    **error);
-gboolean                g_file_contains_file              (GFile                      *parent,
-							   GFile                      *descendant);
+gboolean                g_file_has_prefix                 (GFile                      *file,
+							   GFile                      *prefix);
 char *                  g_file_get_relative_path          (GFile                      *parent,
 							   GFile                      *descendant);
 GFile *                 g_file_resolve_relative_path      (GFile                      *file,
@@ -639,6 +646,9 @@ GFileOutputStream *     g_file_replace_finish             (GFile
 							   GError                    **error);
 gboolean                g_file_query_exists               (GFile                      *file,
 							   GCancellable               *cancellable);
+GFileType               g_file_query_file_type            (GFile                      *file,
+                                                           GFileQueryInfoFlags         flags,
+                                                           GCancellable               *cancellable);
 GFileInfo *             g_file_query_info                 (GFile                      *file,
 							   const char                 *attributes,
 							   GFileQueryInfoFlags         flags,
@@ -658,6 +668,15 @@ GFileInfo *             g_file_query_filesystem_info      (GFile
 							   const char                 *attributes,
 							   GCancellable               *cancellable,
 							   GError                    **error);
+void                    g_file_query_filesystem_info_async (GFile                      *file,
+							   const char                 *attributes,
+							   int                         io_priority,
+							   GCancellable               *cancellable,
+							   GAsyncReadyCallback         callback,
+							   gpointer                    user_data);
+GFileInfo *             g_file_query_filesystem_info_finish (GFile                      *file,
+                                                           GAsyncResult               *res,
+							   GError                    **error);
 GMount *                g_file_find_enclosing_mount       (GFile                      *file,
                                                            GCancellable               *cancellable,
                                                            GError                    **error);
@@ -732,6 +751,9 @@ gboolean                g_file_move                       (GFile
 gboolean                g_file_make_directory             (GFile                      *file,
 							   GCancellable               *cancellable,
 							   GError                    **error);
+gboolean                g_file_make_directory_with_parents (GFile                     *file,
+		                                           GCancellable               *cancellable,
+		                                           GError                    **error);
 gboolean                g_file_make_symbolic_link         (GFile                      *file,
 							   const char                 *symlink_value,
 							   GCancellable               *cancellable,
