@@ -241,10 +241,8 @@ g_memory_output_stream_get_data (GMemoryOutputStream *ostream)
  * Note that for growable streams the returned size may become invalid on
  * the next write or truncate operation on the stream.
  *
- * Note, this does not return the number of bytes written to the stream.
- * In glib 2.18 this is availible with g_memory_output_stream_get_data_size(),
- * but for 2.16 you have to use g_seekable_seek() to %G_SEEK_CUR
- * and call g_seekable_tell() to achive this.
+ * If you want the number of bytes currently written to the stream, use
+ * g_memory_output_stream_get_data_size().
  * 
  * Returns: the number of bytes allocated for the data buffer
  */
@@ -256,6 +254,27 @@ g_memory_output_stream_get_size (GMemoryOutputStream *ostream)
   return ostream->priv->len;
 }
 
+/**
+ * g_memory_output_stream_get_data_size:
+ * @ostream: a #GMemoryOutputStream
+ *
+ * Returns the number of bytes from the start up
+ * to including the last byte written in the stream
+ * that has not been truncated away.
+ * 
+ * Returns: the number of bytes written to the stream
+ *
+ * Since: 2.18
+ */
+gsize
+g_memory_output_stream_get_data_size (GMemoryOutputStream *ostream)
+{
+  g_return_val_if_fail (G_IS_MEMORY_OUTPUT_STREAM (ostream), 0);
+  
+  return ostream->priv->pos;
+}
+
+
 static gboolean
 array_check_boundary (GMemoryOutputStream  *stream,
                       goffset               size,
@@ -308,7 +327,7 @@ array_resize (GMemoryOutputStream  *ostream,
   len = priv->len;
   data = priv->realloc_fn (priv->data, size);
 
-  if (size > 0 && !data) 
+  if (!data) 
     {
       if (allow_partial &&
 	  priv->pos < priv->len)
