@@ -16,35 +16,17 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+
 #ifndef __G_I18N_H__
 #define __G_I18N_H__
 
-#include <glib/gstrfuncs.h>
-
-#ifdef ENABLE_NLS
+#include <glib.h>
 
 #include <libintl.h>
-#define _(String) gettext (String)
-#define Q_(String) g_strip_context ((String), gettext (String))
-#ifdef gettext_noop
-#define N_(String) gettext_noop (String)
-#else
+
+#define  _(String) gettext (String)
+#define Q_(String) g_dpgettext (NULL, String, 0)
 #define N_(String) (String)
-#endif
-
-#else /* NLS is disabled */
-
-#define _(String) (String)
-#define Q_(String) (String)
-#define N_(String) (String)
-#define textdomain(String) (String)
-#define gettext(String) (String)
-#define dgettext(Domain,String) (String)
-#define dcgettext(Domain,String,Type) (String)
-#define bindtextdomain(Domain,Directory) (Domain) 
-
-#endif
+#define C_(Context,String) g_dpgettext (NULL, Context "\004" String, strlen (Context) + 1)
 
 #endif  /* __G_I18N_H__ */
-
-
