@@ -227,122 +227,6 @@ g_io_win32_get_debug_flag (void)
   return (getenv ("G_IO_WIN32_DEBUG") != NULL);
 }
 
-static char *
-winsock_error_message (int number)
-{
-  static char unk[100];
-
-  switch (number) {
-  case WSAEINTR:
-    return "Interrupted function call";
-  case WSAEACCES:
-    return "Permission denied";
-  case WSAEFAULT:
-    return "Bad address";
-  case WSAEINVAL:
-    return "Invalid argument";
-  case WSAEMFILE:
-    return "Too many open sockets";
-  case WSAEWOULDBLOCK:
-    return "Resource temporarily unavailable";
-  case WSAEINPROGRESS:
-    return "Operation now in progress";
-  case WSAEALREADY:
-    return "Operation already in progress";
-  case WSAENOTSOCK:
-    return "Socket operation on nonsocket";
-  case WSAEDESTADDRREQ:
-    return "Destination address required";
-  case WSAEMSGSIZE:
-    return "Message too long";
-  case WSAEPROTOTYPE:
-    return "Protocol wrong type for socket";
-  case WSAENOPROTOOPT:
-    return "Bad protocol option";
-  case WSAEPROTONOSUPPORT:
-    return "Protocol not supported";
-  case WSAESOCKTNOSUPPORT:
-    return "Socket type not supported";
-  case WSAEOPNOTSUPP:
-    return "Operation not supported on transport endpoint";
-  case WSAEPFNOSUPPORT:
-    return "Protocol family not supported";
-  case WSAEAFNOSUPPORT:
-    return "Address family not supported by protocol family";
-  case WSAEADDRINUSE:
-    return "Address already in use";
-  case WSAEADDRNOTAVAIL:
-    return "Address not available";
-  case WSAENETDOWN:
-    return "Network interface is not configured";
-  case WSAENETUNREACH:
-    return "Network is unreachable";
-  case WSAENETRESET:
-    return "Network dropped connection on reset";
-  case WSAECONNABORTED:
-    return "Software caused connection abort";
-  case WSAECONNRESET:
-    return "Connection reset by peer";
-  case WSAENOBUFS:
-    return "No buffer space available";
-  case WSAEISCONN:
-    return "Socket is already connected";
-  case WSAENOTCONN:
-    return "Socket is not connected";
-  case WSAESHUTDOWN:
-    return "Can't send after socket shutdown";
-  case WSAETIMEDOUT:
-    return "Connection timed out";
-  case WSAECONNREFUSED:
-    return "Connection refused";
-  case WSAEHOSTDOWN:
-    return "Host is down";
-  case WSAEHOSTUNREACH:
-    return "Host is unreachable";
-  case WSAEPROCLIM:
-    return "Too many processes";
-  case WSASYSNOTREADY:
-    return "Network subsystem is unavailable";
-  case WSAVERNOTSUPPORTED:
-    return "Winsock.dll version out of range";
-  case WSANOTINITIALISED:
-    return "Successful WSAStartup not yet performed";
-  case WSAEDISCON:
-    return "Graceful shutdown in progress";
-  case WSATYPE_NOT_FOUND:
-    return "Class type not found";
-  case WSAHOST_NOT_FOUND:
-    return "Host not found";
-  case WSATRY_AGAIN:
-    return "Nonauthoritative host not found";
-  case WSANO_RECOVERY:
-    return "This is a nonrecoverable error";
-  case WSANO_DATA:
-    return "Valid name, no data record of requested type";
-  case WSA_INVALID_HANDLE:
-    return "Specified event object handle is invalid";
-  case WSA_INVALID_PARAMETER:
-    return "One or more parameters are invalid";
-  case WSA_IO_INCOMPLETE:
-    return "Overlapped I/O event object not in signaled state";
-  case WSA_NOT_ENOUGH_MEMORY:
-    return "Insufficient memory available";
-  case WSA_OPERATION_ABORTED:
-    return "Overlapped operation aborted";
-  case WSAEINVALIDPROCTABLE:
-    return "Invalid procedure table from service provider";
-  case WSAEINVALIDPROVIDER:
-    return "Invalid service provider version number";
-  case WSAEPROVIDERFAILEDINIT:
-    return "Unable to initialize a service provider";
-  case WSASYSCALLFAILURE:
-    return "System call failure";
-  default:
-    sprintf (unk, "Unknown WinSock error %d", number);
-    return unk;
-  }
-}
-
 static void
 g_io_channel_win32_init (GIOWin32Channel *channel)
 {
@@ -776,16 +660,25 @@ g_io_win32_prepare (GSource *source,
   
   *timeout = -1;
   
+  if (channel->debug)
+    g_print ("g_io_win32_prepare: source=%p channel=%p", source, channel);
+
   switch (channel->type)
     {
     case G_IO_WIN32_WINDOWS_MESSAGES:
+      if (channel->debug)
+	g_print (" MSG");
+      break;
+
     case G_IO_WIN32_CONSOLE:
+      if (channel->debug)
+	g_print (" CON");
       break;
 
     case G_IO_WIN32_FILE_DESC:
       if (channel->debug)
-	g_print ("g_io_win32_prepare: for thread %#x buffer_condition:{%s}\n"
-		 "  watch->pollfd.events:{%s} watch->pollfd.revents:{%s} channel->revents:{%s}\n",
+	g_print (" FD thread=%#x buffer_condition:{%s}"
+		 "\n  watch->pollfd.events:{%s} watch->pollfd.revents:{%s} channel->revents:{%s}",
 		 channel->thread_id, condition_to_string (buffer_condition),
 		 condition_to_string (watch->pollfd.events),
 		 condition_to_string (watch->pollfd.revents),
@@ -797,8 +690,7 @@ g_io_win32_prepare (GSource *source,
 	  if (channel->direction == 0 && channel->wrp == channel->rdp)
 	    {
 	      if (channel->debug)
-		g_print ("g_io_win32_prepare: for thread %#x, setting channel->revents = 0\n",
-			 channel->thread_id);
+		g_print ("\n  setting revents=0");
 	      channel->revents = 0;
 	    }
 	}
@@ -808,8 +700,7 @@ g_io_win32_prepare (GSource *source,
 	      && (channel->wrp + 1) % BUFFER_SIZE == channel->rdp)
 	    {
 	      if (channel->debug)
-		g_print ("g_io_win32_prepare: for thread %#x, setting channel->revents = %i\n",
-			 channel->thread_id, 0);
+		g_print ("\n setting revents=0");
 	      channel->revents = 0;
 	    }
 	}	  
@@ -817,18 +708,19 @@ g_io_win32_prepare (GSource *source,
       break;
 
     case G_IO_WIN32_SOCKET:
+      if (channel->debug)
+	g_print (" SOCK");
       event_mask = 0;
       if (watch->condition & G_IO_IN)
 	event_mask |= (FD_READ | FD_ACCEPT);
       if (watch->condition & G_IO_OUT)
 	event_mask |= (FD_WRITE | FD_CONNECT);
-      if (watch->condition & G_IO_HUP)
-	event_mask |= FD_CLOSE;
+      event_mask |= FD_CLOSE;
 
       if (channel->event_mask != event_mask /* || channel->event != watch->pollfd.fd*/)
 	{
 	  if (channel->debug)
-	    g_print ("g_io_win32_prepare: WSAEventSelect(%d, %#x, {%s}\n",
+	    g_print ("\n  WSAEventSelect(%d,%#x,{%s})",
 		     channel->fd, watch->pollfd.fd,
 		     event_mask_to_string (event_mask));
 	  if (WSAEventSelect (channel->fd, (HANDLE) watch->pollfd.fd,
@@ -838,6 +730,8 @@ g_io_win32_prepare (GSource *source,
 #if 0
 	  channel->event = watch->pollfd.fd;
 #endif
+	  if (channel->debug)
+	    g_print ("\n  setting last_events=0");
 	  channel->last_events = 0;
 	}
       break;
@@ -846,6 +740,9 @@ g_io_win32_prepare (GSource *source,
       g_assert_not_reached ();
       abort ();
     }
+  if (channel->debug)
+    g_print ("\n");
+
   return ((watch->condition & buffer_condition) == watch->condition);
 }
 
@@ -858,14 +755,19 @@ g_io_win32_check (GSource *source)
   GIOCondition buffer_condition = g_io_channel_get_buffer_condition (watch->channel);
   WSANETWORKEVENTS events;
 
+  if (channel->debug)
+    g_print ("g_io_win32_check: source=%p channel=%p", source, channel);
+
   switch (channel->type)
     {
     case G_IO_WIN32_WINDOWS_MESSAGES:
+      if (channel->debug)
+	g_print (" MSG\n");
       return (PeekMessage (&msg, channel->hwnd, 0, 0, PM_NOREMOVE));
 
     case G_IO_WIN32_FILE_DESC:
       if (channel->debug)
-	g_print ("g_io_win32_check: for thread %#x buffer_condition=%s\n"
+	g_print (" FD thread=%#x buffer_condition=%s\n"
 		 "  watch->pollfd.events={%s} watch->pollfd.revents={%s} channel->revents={%s}\n",
 		 channel->thread_id, condition_to_string (buffer_condition),
 		 condition_to_string (watch->pollfd.events),
@@ -877,6 +779,8 @@ g_io_win32_check (GSource *source)
       return ((watch->pollfd.revents | buffer_condition) & watch->condition);
 
     case G_IO_WIN32_CONSOLE:
+      if (channel->debug)
+	g_print (" CON\n");
       if (watch->channel->is_writeable)
 	return TRUE;
       else if (watch->channel->is_readable)
@@ -900,10 +804,12 @@ g_io_win32_check (GSource *source)
       return FALSE;
 
     case G_IO_WIN32_SOCKET:
+      if (channel->debug)
+	g_print (" SOCK");
       if (channel->last_events & FD_WRITE)
 	{
 	  if (channel->debug)
-	    g_print ("g_io_win32_check: sock=%d event=%#x last_events has FD_WRITE\n",
+	    g_print (" sock=%d event=%#x last_events has FD_WRITE",
 		     channel->fd, watch->pollfd.fd);
 	}
       else
@@ -911,10 +817,11 @@ g_io_win32_check (GSource *source)
 	  WSAEnumNetworkEvents (channel->fd, 0, &events);
 
 	  if (channel->debug)
-	    g_print ("g_io_win32_check: WSAEnumNetworkEvents (%d, %#x) revents={%s} condition={%s} events={%s}\n",
-		     channel->fd, watch->pollfd.fd,
+	    g_print ("\n  revents={%s} condition={%s}"
+		     "\n  WSAEnumNetworkEvents(%d,0) sets events={%s}",
 		     condition_to_string (watch->pollfd.revents),
 		     condition_to_string (watch->condition),
+		     channel->fd, 
 		     event_mask_to_string (events.lNetworkEvents));
 	  
 	  if (watch->pollfd.revents != 0 &&
@@ -923,11 +830,11 @@ g_io_win32_check (GSource *source)
 	    {
 	      channel->event_mask = 0;
 	      if (channel->debug)
-		g_print ("g_io_win32_check: WSAEventSelect(%d, %#x, {})\n",
+		g_print ("\n  WSAEventSelect(%d,%#x,{})",
 			 channel->fd, watch->pollfd.fd);
 	      WSAEventSelect (channel->fd, (HANDLE) watch->pollfd.fd, 0);
 	      if (channel->debug)
-		g_print ("g_io_win32_check: ResetEvent(%#x)\n",
+		g_print ("  ResetEvent(%#x)",
 			 watch->pollfd.fd);
 	      ResetEvent ((HANDLE) watch->pollfd.fd);
 	    }
@@ -936,13 +843,37 @@ g_io_win32_check (GSource *source)
       watch->pollfd.revents = 0;
       if (channel->last_events & (FD_READ | FD_ACCEPT))
 	watch->pollfd.revents |= G_IO_IN;
-      if (channel->last_events & (FD_WRITE | FD_CONNECT))
+      if (channel->last_events & FD_WRITE)
 	watch->pollfd.revents |= G_IO_OUT;
-      if (watch->pollfd.revents == 0 && (channel->last_events & (FD_CLOSE)))
-	watch->pollfd.revents |= G_IO_HUP;
+      else
+	{
+	  /* We have called WSAEnumNetworkEvents() above but it didn't
+	   * set FD_WRITE.
+	   */
+	  if (events.lNetworkEvents & FD_CONNECT)
+	    {
+	      if (events.iErrorCode[FD_CONNECT_BIT] == 0)
+		watch->pollfd.revents |= G_IO_OUT;
+	      else
+		watch->pollfd.revents |= (G_IO_HUP | G_IO_ERR);
+	    }
+	  if (watch->pollfd.revents == 0 && (channel->last_events & (FD_CLOSE)))
+	    watch->pollfd.revents |= G_IO_HUP;
+	}
 
-      if (!channel->write_would_have_blocked && (channel->event_mask & FD_WRITE))
-	watch->pollfd.revents |= G_IO_OUT; /* This sucks but... */
+      /* Regardless of WSAEnumNetworkEvents() result, if watching for
+       * writability, unless last write would have blocked set
+       * G_IO_OUT. But never set both G_IO_OUT and G_IO_HUP.
+       */
+      if (!(watch->pollfd.revents & G_IO_HUP) &&
+	  !channel->write_would_have_blocked &&
+	  (channel->event_mask & FD_WRITE))
+	watch->pollfd.revents |= G_IO_OUT;
+
+      if (channel->debug)
+	g_print ("\n  revents={%s} retval={%s}\n",
+		 condition_to_string (watch->pollfd.revents),
+		 condition_to_string ((watch->pollfd.revents | buffer_condition) & watch->condition));
 
       return ((watch->pollfd.revents | buffer_condition) & watch->condition);
 
@@ -986,23 +917,29 @@ g_io_win32_finalize (GSource *source)
   GIOWin32Watch *watch = (GIOWin32Watch *)source;
   GIOWin32Channel *channel = (GIOWin32Channel *)watch->channel;
   
+  if (channel->debug)
+    g_print ("g_io_win32_finalize: source=%p channel=%p", source, channel);
+
   switch (channel->type)
     {
     case G_IO_WIN32_WINDOWS_MESSAGES:
+      if (channel->debug)
+	g_print (" MSG");
+      break;
+
     case G_IO_WIN32_CONSOLE:
+      if (channel->debug)
+	g_print (" CON");
       break;
 
     case G_IO_WIN32_FILE_DESC:
-      LOCK (channel->mutex);
       if (channel->debug)
-	g_print ("g_io_win32_finalize: channel with thread %#x\n",
-		 channel->thread_id);
-      UNLOCK (channel->mutex);
+	g_print (" FD thread=%#x", channel->thread_id);
       break;
 
     case G_IO_WIN32_SOCKET:
       if (channel->debug)
-	g_print ("g_io_win32_finalize: channel is for sock=%d\n", channel->fd);
+	g_print (" SOCK sock=%d", channel->fd);
 #if 0
       CloseHandle ((HANDLE) watch->pollfd.fd);
       channel->event = 0;
@@ -1014,6 +951,8 @@ g_io_win32_finalize (GSource *source)
       g_assert_not_reached ();
       abort ();
     }
+  if (channel->debug)
+    g_print ("\n");
   g_io_channel_unref (watch->channel);
 }
 
@@ -1042,8 +981,8 @@ g_io_win32_msg_read (GIOChannel *channel,
     }
   
   if (win32_channel->debug)
-    g_print ("g_io_win32_msg_read: for %#x\n",
-	     (guint) win32_channel->hwnd);
+    g_print ("g_io_win32_msg_read: channel=%p hwnd=%#x\n",
+	     channel, (guint) win32_channel->hwnd);
   if (!PeekMessage (&msg, win32_channel->hwnd, 0, 0, PM_REMOVE))
     return G_IO_STATUS_AGAIN;
 
@@ -1100,7 +1039,7 @@ g_io_win32_free (GIOChannel *channel)
   GIOWin32Channel *win32_channel = (GIOWin32Channel *)channel;
   
   if (win32_channel->debug)
-    g_print ("g_io_win32_free channel fd=%d\n", win32_channel->fd);
+    g_print ("g_io_win32_free channel=%p fd=%d\n", channel, win32_channel->fd);
 
   if (win32_channel->data_avail_event)
     CloseHandle (win32_channel->data_avail_event);
@@ -1284,7 +1223,7 @@ g_io_win32_fd_close (GIOChannel *channel,
   GIOWin32Channel *win32_channel = (GIOWin32Channel *)channel;
   
   if (win32_channel->debug)
-    g_print ("thread %#x: closing fd %d\n",
+    g_print ("g_io_win32_fd_close: thread=%#x: fd=%d\n",
 	     win32_channel->thread_id,
 	     win32_channel->fd);
   LOCK (win32_channel->mutex);
@@ -1337,8 +1276,9 @@ g_io_win32_fd_create_watch (GIOChannel    *channel,
   watch->pollfd.events = condition;
   
   if (win32_channel->debug)
-    g_print ("g_io_win32_fd_create_watch: fd=%d condition={%s} handle=%#x\n",
-	     win32_channel->fd, condition_to_string (condition), watch->pollfd.fd);
+    g_print ("g_io_win32_fd_create_watch: channel=%p fd=%d condition={%s} event=%#x\n",
+	     channel, win32_channel->fd,
+	     condition_to_string (condition), watch->pollfd.fd);
 
   LOCK (win32_channel->mutex);
   if (win32_channel->thread_id == 0)
@@ -1406,20 +1346,23 @@ g_io_win32_sock_read (GIOChannel *channel,
   int winsock_error;
 
   if (win32_channel->debug)
-    g_print ("g_io_win32_sock_read: sockfd=%d count=%d\n",
-	     win32_channel->fd, count);
+    g_print ("g_io_win32_sock_read: channel=%p sock=%d count=%d",
+	     channel, win32_channel->fd, count);
 
   result = recv (win32_channel->fd, buf, count, 0);
   if (result == SOCKET_ERROR)
     winsock_error = WSAGetLastError ();
 
   if (win32_channel->debug)
-    g_print ("g_io_win32_sock_read: recv=%d %s\n",
-	     result,
-	     (result == SOCKET_ERROR ? winsock_error_message (winsock_error) : ""));
+    g_print (" recv=%d", result);
   
   if (result == SOCKET_ERROR)
     {
+      gchar *emsg = g_win32_error_message (winsock_error);
+
+      if (win32_channel->debug)
+	g_print (" %s\n", emsg);
+
       *bytes_read = 0;
 
       switch (winsock_error)
@@ -1428,17 +1371,21 @@ g_io_win32_sock_read (GIOChannel *channel,
           error = G_IO_CHANNEL_ERROR_INVAL;
           break;
 	case WSAEWOULDBLOCK:
+	  g_free (emsg);
           return G_IO_STATUS_AGAIN;
 	default:
 	  error = G_IO_CHANNEL_ERROR_FAILED;
           break;
 	}
-      g_set_error (err, G_IO_CHANNEL_ERROR, error,
-		   winsock_error_message (winsock_error));
+      g_set_error (err, G_IO_CHANNEL_ERROR, error, emsg);
+      g_free (emsg);
+
       return G_IO_STATUS_ERROR;
     }
   else
     {
+      if (win32_channel->debug)
+	g_print ("\n");
       *bytes_read = result;
       if (result == 0)
 	return G_IO_STATUS_EOF;
@@ -1460,20 +1407,23 @@ g_io_win32_sock_write (GIOChannel  *channel,
   int winsock_error;
   
   if (win32_channel->debug)
-    g_print ("g_io_win32_sock_write: sockfd=%d count=%d\n",
-	     win32_channel->fd, count);
+    g_print ("g_io_win32_sock_write: channel=%p sock=%d count=%d",
+	     channel, win32_channel->fd, count);
 
   result = send (win32_channel->fd, buf, count, 0);
   if (result == SOCKET_ERROR)
     winsock_error = WSAGetLastError ();
 
   if (win32_channel->debug)
-    g_print ("g_io_win32_sock_write: send=%d %s\n",
-	     result,
-	     (result == SOCKET_ERROR ? winsock_error_message (winsock_error) : ""));
+    g_print (" send=%d", result);
   
   if (result == SOCKET_ERROR)
     {
+      gchar *emsg = g_win32_error_message (winsock_error);
+
+      if (win32_channel->debug)
+	g_print (" %s\n", emsg);
+
       *bytes_written = 0;
 
       switch (winsock_error)
@@ -1484,18 +1434,21 @@ g_io_win32_sock_write (GIOChannel  *channel,
 	case WSAEWOULDBLOCK:
 	  win32_channel->write_would_have_blocked = TRUE;
 	  win32_channel->last_events = 0;
+	  g_free (emsg);
           return G_IO_STATUS_AGAIN;
 	default:
 	  error = G_IO_CHANNEL_ERROR_FAILED;
           break;
 	}
-      g_set_error (err, G_IO_CHANNEL_ERROR, error,
-		   winsock_error_message (winsock_error));
+      g_set_error (err, G_IO_CHANNEL_ERROR, error, emsg);
+      g_free (emsg);
 
       return G_IO_STATUS_ERROR;
     }
   else
     {
+      if (win32_channel->debug)
+	g_print ("\n");
       *bytes_written = result;
       win32_channel->write_would_have_blocked = FALSE;
 
@@ -1512,8 +1465,8 @@ g_io_win32_sock_close (GIOChannel *channel,
   if (win32_channel->fd != -1)
     {
       if (win32_channel->debug)
-	g_print ("g_io_win32_sock_close: closing socket %d\n",
-		 win32_channel->fd);
+	g_print ("g_io_win32_sock_close: channel=%p sock=%d\n",
+		 channel, win32_channel->fd);
       
       closesocket (win32_channel->fd);
       win32_channel->fd = -1;
@@ -1544,8 +1497,8 @@ g_io_win32_sock_create_watch (GIOChannel    *channel,
   watch->pollfd.events = condition;
   
   if (win32_channel->debug)
-    g_print ("g_io_win32_sock_create_watch: sock=%d handle=%#x condition={%s}\n",
-	     win32_channel->fd, watch->pollfd.fd,
+    g_print ("g_io_win32_sock_create_watch: channel=%p sock=%d event=%#x condition={%s}\n",
+	     channel, win32_channel->fd, watch->pollfd.fd,
 	     condition_to_string (watch->condition));
 
   g_source_add_poll (source, &watch->pollfd);
@@ -1640,7 +1593,7 @@ g_io_channel_new_file (const gchar  *filename,
 
   if (g_io_win32_get_debug_flag ())
     {
-      g_print ("g_io_channel_win32_new_file: open(\"%s\", ", filename);
+      g_print ("g_io_channel_win32_new_file: open(\"%s\",", filename);
       g_win32_print_access_mode (flags|_O_BINARY);
       g_print (",%#o)=%d\n", pmode, fid);
     }
@@ -1830,9 +1783,13 @@ g_io_win32_sock_set_flags (GIOChannel *channel,
       arg = 1;
       if (ioctlsocket (win32_channel->fd, FIONBIO, &arg) == SOCKET_ERROR)
 	{
+	  gchar *emsg = g_win32_error_message (WSAGetLastError ());
+
 	  g_set_error (err, G_IO_CHANNEL_ERROR,
 		       G_IO_CHANNEL_ERROR_FAILED,
-		       winsock_error_message (WSAGetLastError ()));
+		       emsg);
+	  g_free (emsg);
+
 	  return G_IO_STATUS_ERROR;
 	}
     }
@@ -1841,9 +1798,13 @@ g_io_win32_sock_set_flags (GIOChannel *channel,
       arg = 0;
       if (ioctlsocket (win32_channel->fd, FIONBIO, &arg) == SOCKET_ERROR)
 	{
+	  gchar *emsg = g_win32_error_message (WSAGetLastError ());
+
 	  g_set_error (err, G_IO_CHANNEL_ERROR,
 		       G_IO_CHANNEL_ERROR_FAILED,
-		       winsock_error_message (WSAGetLastError ()));
+		       emsg);
+	  g_free (emsg);
+
 	  return G_IO_STATUS_ERROR;
 	}
     }
@@ -1911,7 +1872,8 @@ g_io_channel_win32_new_messages (guint hwnd)
   g_io_channel_init (channel);
   g_io_channel_win32_init (win32_channel);
   if (win32_channel->debug)
-    g_print ("g_io_channel_win32_new_messages: hwnd=%#x\n", hwnd);
+    g_print ("g_io_channel_win32_new_messages: channel=%p hwnd=%#x\n",
+	     channel, hwnd);
   channel->funcs = &win32_channel_msg_funcs;
   win32_channel->type = G_IO_WIN32_WINDOWS_MESSAGES;
   win32_channel->hwnd = (HWND) hwnd;
@@ -1941,7 +1903,9 @@ g_io_channel_win32_new_fd_internal (gint         fd,
   win32_channel->fd = fd;
 
   if (win32_channel->debug)
-    g_print ("g_io_channel_win32_new_fd: %u\n", fd);
+    g_print ("g_io_channel_win32_new_fd: channel=%p fd=%u\n",
+	     channel, fd);
+
   if (st->st_mode & _S_IFCHR) /* console */
     {
       channel->funcs = &win32_channel_console_funcs;
@@ -1989,7 +1953,8 @@ g_io_channel_win32_new_socket (int socket)
   g_io_channel_init (channel);
   g_io_channel_win32_init (win32_channel);
   if (win32_channel->debug)
-    g_print ("g_io_channel_win32_new_socket: sockfd=%d\n", socket);
+    g_print ("g_io_channel_win32_new_socket: channel=%p sock=%d\n",
+	     channel, socket);
   channel->funcs = &win32_channel_sock_funcs;
   win32_channel->type = G_IO_WIN32_SOCKET;
   win32_channel->fd = socket;
