@@ -215,14 +215,20 @@ set_error (GMarkupParseContext *context,
 {
   GError *tmp_error;
   gchar *s;
+  gchar *s_valid;
   va_list args;
 
   va_start (args, format);
   s = g_strdup_vprintf (format, args);
   va_end (args);
 
-  tmp_error = g_error_new_literal (G_MARKUP_ERROR, code, s);
+  /* Make sure that the GError message is valid UTF-8 even if it is 
+   * complaining about invalid UTF-8 in the markup: */
+  s_valid = _g_utf8_make_valid (s);
+  tmp_error = g_error_new_literal (G_MARKUP_ERROR, code, s_valid);
+
   g_free (s);
+  g_free (s_valid);
 
   g_prefix_error (&tmp_error,
                   _("Error on line %d char %d: "),
@@ -1892,7 +1898,7 @@ g_markup_parse_context_get_element (GMarkupParseContext *context)
  *
  * Returns: the element stack, which must not be modified
  *
- * Since 2.16
+ * Since: 2.16
  **/
 G_CONST_RETURN GSList *
 g_markup_parse_context_get_element_stack (GMarkupParseContext *context)
